@@ -38,6 +38,7 @@
 (declare-function eshell-parse-arguments "esh-arg" (beg end))
 (declare-function eshell-backward-argument "esh-mode" (&optional arg))
 (declare-function helm-quote-whitespace "helm-lib")
+(defvar eshell-special-chars-outside-quoting)
 
 
 (defgroup helm-eshell nil
@@ -98,6 +99,8 @@
 (defun helm-ec-insert (_candidate)
   "Replace text at point with CANDIDATE.
 The function that call this should set `helm-ec-target' to thing at point."
+  (set (make-local-variable 'comint-file-name-quote-list)
+       eshell-special-chars-outside-quoting)
   (let ((pt (point)))
     (when (and helm-ec-target
                (search-backward helm-ec-target nil t)
@@ -109,12 +112,14 @@ The function that call this should set `helm-ec-target' to thing at point."
      (mapconcat
       (lambda (x)
         (cond ((string-match "\\`~/?" helm-ec-target)
-               (helm-quote-whitespace (abbreviate-file-name x)))
+               ;; Strip out the first escape char added by
+               ;; `comint-quote-filename' before "~" (Issue #1803).
+               (substring (comint-quote-filename (abbreviate-file-name x)) 1))
               ((string-match "\\`/" helm-ec-target)
-               (helm-quote-whitespace x))
+               (comint-quote-filename x))
               (t
                (concat (and (string-match "\\`[.]/" helm-ec-target) "./")
-                       (helm-quote-whitespace
+                       (comint-quote-filename
                         (file-relative-name x))))))
       marked " "))))
 
