@@ -426,7 +426,12 @@ The directory selection with \"**/\" like bash shopt globstar option is not supp
 
 *** Query replace regexp on filenames
 
-You can rename your files by replacing only part of filenames matching
+WARNING: This is designed to work ONLY in current directory, i.e
+         your marked files have to be from the same directory.
+         So do not mark files in different directories, [[Using wildcard to select multiple files][recursive globbing]] e.g \"**.txt\"
+         is not supported as well for same reasons. 
+
+You can rename your marked files by replacing only part of filenames matching
 a regexp.
 
 e.g Rename recursively all files with \".JPG\" extension to \".jpg\":
@@ -452,22 +457,55 @@ e.g To rename the files \"foo.jpg\" \"bar.jpg\" and \"baz.jpg\"
     to \"foo-001.jpg\" \"foo-002.jpg\" \"foo-003.jpg\"
 
 Use as replace regexp \"%.\" and as replacement string \"foo-\\#\".
-Where \"%.\" is same as regexp \".*\\.jpg\".
 
-Note: You can do this with the serial renames actions you will find in the action menu
-      for more sophisticated renaming, but using query replace regexp on filenames
-      is a fast way for most common serial replacements.
+When \"%\", \".%\" or \"%\" are used, \"\\@\" can be used as a placeholder which
+remember those values.
 
-Note also that unlike the serial rename actions the renamed files stay in their initial directory
-and are not renamed to current directory, IOW use this (\\#) to rename files inside current directory.
+e.g To rename the files \"foo.jpg\" \"bar.jpg\" and \"baz.jpg\"
+    to \"foo-001.jpg\" \"bar-002.jpg\" \"baz-003.jpg\"
+
+Use as replace regexp \"%.\" and as replacement string \"\\@-\\#\".
+
+Modifying the placeholder (\\@) is possible
+\(in contrast of renaming the whole placeholder with something else) with two methods:
+
+- By substring, i.e using only the substring of placeholder:
+    \\@:<from>:<to>
+  e.g \\@:0:2 replaces from beginning to second char of placeholder
+  Note that length of placeholder is used for <to> when <to> is not specified
+  e.g \\@:2: replaces from second char of placeholder to end
+
+- By search and replace:
+    \\@/<regexp>/<replacement>
+  e.g \\@/foo/bar replaces \"foo\" in placeholder by \"bar\"
+  Incremental replacement is also handled in <replacement>
+  e.g \\@/foo/-\\# replaces \"foo\" in placeholder by 001, 002 etc...
 
 In the second prompt (replace regexp with) shortcut for `upcase', `downcase' and `capitalize'
 are available, respectively `%u', `%d' and `%c'.
 
+Note also that unlike the [[Serial renaming][serial rename]] actions the renamed files stay in their initial directory
+and are not renamed to current directory, IOW use this (\\#) to rename files inside the same directory.
+
+*** Serial renaming
+
+You can use the serial rename actions to rename, copy or symlink marked files to
+a specific directory or in the current one with all your files numbered incrementally.
+
+- Serial rename by renaming
+Rename all marked files with incremental number to a specific directory.
+- Serial rename by copying
+Copy all marked files with incremental number to a specific directory.
+-Serial rename by symlinking
+Symlink all marked files with incremental number to a specific directory.
+
 *** Edit marked files in a dired buffer
 
 You can open a dired buffer with only marked files with `\\<helm-find-files-map>\\[helm-ff-run-marked-files-in-dired]'
 With a prefix arg you can open this same dired buffer in wdired mode for editing files.
+Note that wildcards are supported as well, so you can use e.g \"*.txt\" to select all \".txt\" files
+in current directory or \"**.txt\" to select all files recursively from current directory
+\(See [[Using wildcard to select multiple files]] section above).
 
 *** Copying renaming asynchronously
 
@@ -478,6 +516,10 @@ Note that even when async is enabled, running a copy/rename action with a prefix
 will execute action synchronously, it will follow also the first file of the marked files
 in its destination directory.
 
+When `dired-async-mode' is enabled and additional action named \"Backup files\" will be
+available (such command is not available in emacs natively).
+See [[Using wildcard to select multiple files]] for details.
+
 *** Bookmark your `helm-find-files' session
 
 You can bookmark your `helm-find-files' session with `C-x r m'.
@@ -510,6 +552,11 @@ All these grep commands are using symbol at point as default pattern.
 Note that default is a different thing than input (nothing is added to
 prompt until you hit `M-n').
 
+**** Grepping on remote files
+On remote files grep is not well supported by tramp unless you suspend update before
+entering your pattern and reenable it once your pattern is ready.
+To toggle suspend update use \\<helm-map>\\[helm-toggle-suspend-update].
+
 *** Setting up aliases in eshell allows you to setup powerful customized commands
 
 Adding eshell aliases to your `eshell-aliases-file' or using the
@@ -549,8 +596,8 @@ Of course the alias command should support this.
 this is controled by `helm-ff-tramp-not-fancy' variable, if you change this,
 expect helm becoming very slow unless your connection is super fast.
 
-- Grepping files is not very well supported when used incrementally, see above
-grep section.
+- Grepping files is not very well supported when used incrementally,
+see above [[Grepping on remote files]].
 
 - Locate is not working on remote directories.
 
@@ -599,10 +646,17 @@ Use the sudo method:
 
 *** Attach files to a mail buffer (message-mode)
 
-If you are in a message buffer, the action will appear in action menu, otherwise
-it available at any time with \\<helm-find-files-map>\\[helm-ff-run-gnus-attach-files]
-See how behave `gnus-attach-files' for more infos.
-NOTE: Even if called `gnus-attach-files' it works with mu4e and else.
+If you are in a `message-mode' or `mail-mode' buffer, the action will
+appear in action menu, otherwise it is available at any time with
+\\<helm-find-files-map>\\[helm-ff-run-mail-attach-files] Here how it
+behave:
+- If you are in a (mail or message) buffer, files are attached
+there.
+- If you are not in a mail buffer but one or more mail buffer
+exists, you are prompted to add attached file to one of these mail
+buffer.
+- If you are not in a mail buffer and no mail buffer exists,
+a new mail buffer is created with tha attached files in it.
 
 ** Commands
 \\<helm-find-files-map>
